aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/python/ops/linalg/linear_operator.py
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/python/ops/linalg/linear_operator.py')
-rw-r--r--tensorflow/python/ops/linalg/linear_operator.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/tensorflow/python/ops/linalg/linear_operator.py b/tensorflow/python/ops/linalg/linear_operator.py
index 8cfe964b1c..20c46fbb82 100644
--- a/tensorflow/python/ops/linalg/linear_operator.py
+++ b/tensorflow/python/ops/linalg/linear_operator.py
@@ -42,7 +42,7 @@ __all__ = ["LinearOperator"]
class LinearOperator(object):
"""Base class defining a [batch of] linear operator[s].
- Subclasses of `LinearOperator` provide a access to common methods on a
+ Subclasses of `LinearOperator` provide access to common methods on a
(batch) matrix, without the need to materialize the matrix. This allows:
* Matrix free computations
@@ -69,11 +69,11 @@ class LinearOperator(object):
#### Shape compatibility
- `LinearOperator` sub classes should operate on a [batch] matrix with
+ `LinearOperator` subclasses should operate on a [batch] matrix with
compatible shape. Class docstrings should define what is meant by compatible
- shape. Some sub-classes may not support batching.
+ shape. Some subclasses may not support batching.
- An example is:
+ Examples:
`x` is a batch matrix with compatible shape for `matmul` if